==> xdtp-1.2.0.tgz: xdtp-1.2.0/sample/xdtp/xdtp_sample.cpp <==
/* 
 * $Id: xdtp_sample.cpp,v 1.6 2006/06/20 13:49:23 ozawa Exp $
 *
 * This sample program is transform a glsd.xml to html.
 *
 * Copyright 2005- ONGS Inc.
 * 
 * author: Masanori OZAWA (ozawa@ongs.co.jp)
 * version: $Revision: 1.6 $
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions
 * are met:
 * 
 *   1. Redistributions of source code must retain the above copyright
 *      notice, this list of conditions and the following disclaimer.
 *   2. Redistributions in binary form must reproduce the above copyright
 *      notice, this list of conditions and the following disclaimer in the
 *      documentation and/or other materials provided with the distribution.
 * 
 * THIS SOFTWARE IS PROVIDED BY ONGS INC ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL ONGS INC OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 * The views and conclusions contained in the software and documentation are
 * those of the authors and should not be interpreted as representing official
 * policies, either expressed or implied, of the ONGS Inc.
 * 
 */

#include <stdio.h>
#include <locale.h>

#include "xdtptypes.h"
#include "XDTPTransform.h"

#include "modules/GLSDModule.h"
#include "modules/GLSDModuleChecker.h"
#include "modules/GLSDDocumentModule.h"
#include "modules/GLSDDocumentModuleChecker.h"

int main(int argc, char *argv[])
{
    // initialize locale
	char *lc = getenv("LC_ALL");

	if (!lc) lc = getenv("LANG");
	if (lc) setlocale(LC_ALL, lc);

    // initialize glibmm
    Glib::init();
    
	// set option
    bool bSuccess = false;
    XDTP::XDTPTransform xdtp;
    XDTP::XDTPModule *glsdm = new XDTP::GLSDModule;
    XDTP::XDTPChecker *glsdc = new XDTP::GLSDModuleChecker;
    XDTP::XDTPModule *glsddm = new XDTP::GLSDDocumentModule;
    XDTP::XDTPChecker*glsddc = new XDTP::GLSDDocumentModuleChecker;

	xdtp.setOutputType("html");
	xdtp.setVerboseMode(1);
	xdtp.setOutputEncoding("UTF-8");
	xdtp.addXSLFile("/usr/local/share/xdtp/toHTML/GLSD.xsl", true);
	xdtp.addXDTPModule(glsdm, glsdc);
	xdtp.addXDTPModule(glsddm, glsddc);
    xdtp.addOption("alias_file=aliases.xml");

    // do transform
    try {
        if (!xdtp.initialize()) {
            THROW("Unable to initialize the XDTPTransform module.");
        }
		bSuccess = xdtp.transform("glsd.xml", "glsd.html");
        if (!bSuccess) {
			xdtp.showErrorMsg();
		}
        xdtp.uninitialize();
    }
    catch (XDTP::Exception exception) {
        exception.print(stderr);
    }
    catch (Glib::Error error) {
        std::string msg = Glib::locale_from_utf8(error.what());
        fprintf(stderr, "xdtp_sample: %s" LINE_SEP, msg.c_str());
    }
    catch (std::exception exception) {
        fprintf(stderr, "xdtp_sample: %s" LINE_SEP, exception.what());
    }
    catch (...) {
        fprintf(stderr, "xdtp_sample: exception occuerd: unknown error." LINE_SEP);
    }
    
    delete glsdm;
    delete glsdc;
    delete glsddm;
    delete glsddc;

    return (bSuccess ? 0 : -1);
}

==> xdtp-1.3.1.tgz: xdtp-1.3.1/sample/xdtp/xdtp_sample.cpp <==
/* 
 * $Id: xdtp_sample.cpp,v 1.7 2008/11/18 10:32:18 ozawa Exp $
 *
 * This sample program is transform a glsd.xml to html.
 *
 * Copyright 2005- ONGS Inc.
 * 
 * author: Masanori OZAWA (ozawa@ongs.co.jp)
 * version: $Revision: 1.7 $
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions
 * are met:
 * 
 *   1. Redistributions of source code must retain the above copyright
 *      notice, this list of conditions and the following disclaimer.
 *   2. Redistributions in binary form must reproduce the above copyright
 *      notice, this list of conditions and the following disclaimer in the
 *      documentation and/or other materials provided with the distribution.
 * 
 * THIS SOFTWARE IS PROVIDED BY ONGS INC ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL ONGS INC OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 * The views and conclusions contained in the software and documentation are
 * those of the authors and should not be interpreted as representing official
 * policies, either expressed or implied, of the ONGS Inc.
 * 
 */

#include <stdio.h>
#include <locale.h>

#include "xdtptypes.h"
#include "XDTPTransform.h"

#include "modules/GLSDModule.h"
#include "modules/GLSDModuleChecker.h"
#include "modules/GLSDDocumentModule.h"
#include "modules/GLSDDocumentModuleChecker.h"

int main(int argc, char *argv[])
{
    // initialize locale
	char *lc = getenv("LC_ALL");

	if (!lc) lc = getenv("LANG");
	if (lc) setlocale(LC_ALL, lc);

    // initialize glibmm
    Glib::init();
    
	// set option
    bool bSuccess = false;
    XDTP::XDTPTransform xdtp;
    XDTP::XDTPModule *glsdm = new XDTP::GLSDModule;
    XDTP::XDTPChecker *glsdc = new XDTP::GLSDModuleChecker;
    XDTP::XDTPModule *glsddm = new XDTP::GLSDDocumentModule;
    XDTP::XDTPChecker*glsddc = new XDTP::GLSDDocumentModuleChecker;

	xdtp.setOutputType("html");
	xdtp.setVerboseMode(1);
	xdtp.setOutputEncoding("UTF-8");
	xdtp.addXSLFile("/usr/local/share/xdtp/toHTML/GLSD.xsl", true);
	xdtp.addXDTPModule(glsdm, glsdc);
	xdtp.addXDTPModule(glsddm, glsddc);
    xdtp.addOption("alias_file=aliases.xml");

    // do transform
    try {
        if (!xdtp.initialize()) {
            THROW("Unable to initialize the XDTPTransform module.");
        }
		bSuccess = xdtp.transform("glsd.xml", "glsd.html");
        if (!bSuccess) {
			xdtp.showErrorMsg();
		}
        xdtp.uninitialize();
    }
    catch (std::exception &exception) {
    	XDTP::Exception::print(stderr, exception);
    }
    catch (Glib::Error &error) {
        std::string msg = Glib::locale_from_utf8(error.what());
        fprintf(stderr, "xdtp_sample: %s" LINE_SEP, msg.c_str());
    }
    catch (...) {
        fprintf(stderr, "xdtp_sample: exception occuerd: unknown error." LINE_SEP);
    }
    
    delete glsdm;
    delete glsdc;
    delete glsddm;
    delete glsddc;

    return (bSuccess ? 0 : -1);
}
